@@ -35,14 +35,13 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 # Preloaded methods go here.
 
 sub new {
 	my ($class,%args) = @_;
-	my $self = bless \%args, $class;
-	$self;
+	bless \%args, $class;
 }
 
 sub hit {
@@ -95,7 +94,7 @@ Logfile::EPrints - Parse Apache logs from GNU EPrints
 	),
   );
   open my $fh, "<access_log" or die $!;
-  $parser->parse_file($fh);
+  $parser->parse_fh($fh);
 
   package MyHandler;
 
@@ -117,25 +116,17 @@ The Logfile::* modules provide a means to analyze log files from Web servers (ty
 
 The architectural design consists of a series of pluggable filters that read from a log file or stream into Perl objects/callbacks. The first filter in the stream needs to convert from the log file format into a Perl object representing a single "hit". Subsequent filters can then ignore hits (e.g. from robots) and/or augment them with additional data (e.g. country of origin by GeoIP).
 
-=head1 CALLBACKS
-
-See Logfile::Hit for the fields available from the 'hit' object.
-
-=head2 Filter Callbacks
+=head1 HANDLER CALLBACKS
 
 =over 4
 
-=item abstract($handler,$hit)
+=item abstract()
 
-=item browse($handler,$hit)
+=item browse()
 
-=item fulltext($handler,$hit)
+=item fulltext()
 
-=item repeated($handler,$hit)
-
-Repeated is implemented by Logfile::Repeated
-
-=item search($handler,$hit)
+=item search()
 
 =back
 
@@ -145,13 +136,6 @@ Repeated is implemented by Logfile::Repeated
 
 Timothy D Brody, E<lt>tdb01r@ecs.soton.ac.ukE<gt>
 
-=head1 TODO
-
-Robots filter:
-
-=item Exclude users that request robots.txt (probably requires persistent storage)
-=item Exclude users by user-agent string
-
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (C) 2005 by Timothy D Brody
